@@ -2,11 +2,10 @@
  *
  * hmm_bcsft.c
  *
- * copyright (c) 2001-9, Karl W Broman
+ * copyright (c) 2001-2022, Karl W Broman
  * modified from hmm_f2.c by Brian S Yandell and Laura M Shannon (c) 2010
  *
- * modified Jun, 2010
- * last modified Apr, 2009
+ * last modified Dec, 2022
  * first written Feb, 2001
  *
  *     This program is free software; you can redistribute it and/or
@@ -41,7 +40,6 @@
 #include <stdio.h>
 #include <R.h>
 #include <Rmath.h>
-#include <R_ext/PrtUtil.h>
 #include "hmm_main.h"
 #include "hmm_bcsft.h"
 #include "hmm_f2.h"
@@ -655,7 +653,7 @@ void est_map_bcsft(int *n_ind, int *n_mar, int *geno, double *rf,
     if(*verbose) {
         ndigits = (int)ceil(-log10(*tol));
         if(ndigits > 16) ndigits=16;
-        sprintf(pattern, "%s%d.%df", "%", ndigits+3, ndigits+1);
+        snprintf(pattern, sizeof(pattern), "%s%d.%df", "%", ndigits+3, ndigits+1);
     }
 
     /* begin EM algorithm */
@@ -741,7 +739,7 @@ void est_map_bcsft(int *n_ind, int *n_mar, int *geno, double *rf,
                 if(rf[j] < *tol/1000.0) rf[j] = *tol/1000.0;
                 else if(rf[j] > 0.5-*tol/1000.0) rf[j] = 0.5-*tol/1000.0;
             }
-            sprintf(text, "%s%s\n", "  max rel've change = ", pattern);
+            snprintf(text, sizeof(text), "%s%s\n", "  max rel've change = ", pattern);
             Rprintf(text, maxdif);
         }
 
@@ -786,7 +784,7 @@ void est_map_bcsft(int *n_ind, int *n_mar, int *geno, double *rf,
                 temp = fabs(rf[j] - cur_rf[j])/(cur_rf[j]+*tol*100.0);
                 if(maxdif < temp) maxdif = temp;
             }
-            sprintf(text, "%s%s\n", "  max rel've change at last step = ", pattern);
+            snprintf(text, sizeof(text), "%s%s\n", "  max rel've change at last step = ", pattern);
             Rprintf(text, maxdif);
         }
 
