@@ -2,9 +2,9 @@
  *
  * hmm_main.c
  *
- * copyright (c) 2001-2010, Karl W Broman
+ * copyright (c) 2001-2022, Karl W Broman
  *
- * last modified Aug, 2010
+ * last modified Dec, 2022
  * first written Feb, 2001
  *
  *     This program is free software; you can redistribute it and/or
@@ -34,7 +34,6 @@
 #include <stdio.h>
 #include <R.h>
 #include <Rmath.h>
-#include <R_ext/PrtUtil.h>
 #include <R_ext/Utils.h>
 #include "hmm_main.h"
 #include "util.h"
@@ -94,8 +93,8 @@ void calc_genoprob(int n_ind, int n_pos, int n_gen, int *geno,
     int cross_scheme[2];
 
     /* cross scheme hidden in genoprob argument; used by hmm_bcsft */
-    cross_scheme[0] = genoprob[0];
-    cross_scheme[1] = genoprob[1];
+    cross_scheme[0] = (int)genoprob[0];
+    cross_scheme[1] = (int)genoprob[1];
     genoprob[0] = 0.0;
     genoprob[1] = 0.0;
 
@@ -192,8 +191,8 @@ void calc_genoprob_special(int n_ind, int n_pos, int n_gen, int *geno,
     int cross_scheme[2];
 
     /* cross scheme hidden in genoprob argument; used by hmm_bcsft */
-    cross_scheme[0] = genoprob[0];
-    cross_scheme[1] = genoprob[1];
+    cross_scheme[0] = (int)genoprob[0];
+    cross_scheme[1] = (int)genoprob[1];
     genoprob[0] = 0.0;
     genoprob[1] = 0.0;
 
@@ -477,7 +476,7 @@ void est_map(int n_ind, int n_mar, int n_gen, int *geno, double *rf,
     if(verbose) {
         ndigits = (int)ceil(-log10(tol));
         if(ndigits > 16) ndigits=16;
-        sprintf(pattern, "%s%d.%df", "%", ndigits+3, ndigits+1);
+        snprintf(pattern, sizeof(pattern), "%s%d.%df", "%", ndigits+3, ndigits+1);
     }
 
     /* begin EM algorithm */
@@ -577,7 +576,7 @@ void est_map(int n_ind, int n_mar, int n_gen, int *geno, double *rf,
                     Rprintf("%d %f %f\n", j+1, cur_rf[j], rf[j]);
                 /* bsy add */
             }
-            sprintf(text, "%s%s\n", "  max rel've change = ", pattern);
+            snprintf(text, sizeof(text), "%s%s\n", "  max rel've change = ", pattern);
             Rprintf(text, maxdif);
         }
 
@@ -637,7 +636,7 @@ void est_map(int n_ind, int n_mar, int n_gen, int *geno, double *rf,
                     if(maxdif < temp) maxdif = temp;
                 }
             }
-            sprintf(text, "%s%s\n", "  max rel've change at last step = ", pattern);
+            snprintf(text, sizeof(text), "%s%s\n", "  max rel've change at last step = ", pattern);
             Rprintf(text, maxdif);
         }
 
@@ -875,8 +874,8 @@ void est_rf(int n_ind, int n_mar, int *geno, double *rf,
     int cross_scheme[2];
 
     /* cross scheme hidden in rf argument; used by hmm_bcsft */
-    cross_scheme[0] = rf[0];
-    cross_scheme[1] = rf[1];
+    cross_scheme[0] = (int)rf[0];
+    cross_scheme[1] = (int)rf[1];
     rf[0] = 0.0;
     rf[1] = 0.0;
 
@@ -1005,8 +1004,8 @@ void calc_pairprob(int n_ind, int n_pos, int n_gen, int *geno,
     int cross_scheme[2];
 
     /* cross scheme hidden in genoprob argument; used by hmm_bcsft */
-    cross_scheme[0] = genoprob[0];
-    cross_scheme[1] = genoprob[1];
+    cross_scheme[0] = (int)genoprob[0];
+    cross_scheme[1] = (int)genoprob[1];
     genoprob[0] = 0.0;
     genoprob[1] = 0.0;
 
